@@ -91,6 +91,8 @@ import com.sun.j3d.exp.swing.JCanvas3D;
  * @author Emmanuel Puybaret
  */
 class MacOSXConfiguration {
+  private static boolean fullScreen;
+
   private MacOSXConfiguration() {    
   }
   
@@ -471,8 +473,12 @@ class MacOSXConfiguration {
       final JToolBar toolBar = toolBars.get(0);
       toolBar.setFloatable(false);
       toolBar.setBorder(new AbstractBorder() {
-          private final Color TOP_GRADIENT_COLOR_ACTIVATED_FRAME = new Color(222, 222, 222);
-          private final Color BOTTOM_GRADIENT_COLOR_ACTIVATED_FRAME = new Color(178, 178, 178);
+          private final Color TOP_GRADIENT_COLOR_ACTIVATED_FRAME = OperatingSystem.isMacOSXYosemiteOrSuperior() 
+              ? new Color(212, 212, 212)
+              : new Color(222, 222, 222);
+          private final Color BOTTOM_GRADIENT_COLOR_ACTIVATED_FRAME = OperatingSystem.isMacOSXYosemiteOrSuperior() 
+              ? new Color(209, 209, 209)
+              : new Color(178, 178, 178);
           private final Color TOP_GRADIENT_COLOR_DEACTIVATED_FRAME  = new Color(244, 244, 244);
           private final Color BOTTOM_GRADIENT_COLOR_DEACTIVATED_FRAME = TOP_GRADIENT_COLOR_ACTIVATED_FRAME;
 
@@ -543,11 +549,13 @@ class MacOSXConfiguration {
               Class fullScreenUtilitiesClass = Class.forName("com.apple.eawt.FullScreenUtilities");
               this.fullScreenListener = new FullScreenAdapter() {
                   public void windowEnteredFullScreen(FullScreenEvent ev) {
+                    fullScreen = true;
                     toolBar.removeMouseListener(mouseListener);
                     toolBar.removeMouseMotionListener(mouseListener);
                   }
                   
                   public void windowExitedFullScreen(FullScreenEvent ev) {
+                    fullScreen = false;
                     toolBar.addMouseListener(mouseListener);
                     toolBar.addMouseMotionListener(mouseListener);
                   }
@@ -603,4 +611,11 @@ class MacOSXConfiguration {
       }
     }
   }
+
+  /**
+   * Returns <code>true</code> if the given window is displayed in full screen mode.
+   */
+  public static boolean isWindowFullScreen(final JFrame frame) {
+    return fullScreen;
+  }
 }
