@@ -24,6 +24,7 @@ import java.awt.Color;
 import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.EventQueue;
+import java.awt.Font;
 import java.awt.Insets;
 import java.awt.KeyboardFocusManager;
 import java.awt.Toolkit;
@@ -52,13 +53,16 @@ import javax.swing.JButton;
 import javax.swing.JComponent;
 import javax.swing.JOptionPane;
 import javax.swing.JRootPane;
+import javax.swing.JTable;
 import javax.swing.JToggleButton;
 import javax.swing.JToolBar;
 import javax.swing.KeyStroke;
 import javax.swing.SwingUtilities;
 import javax.swing.Timer;
 import javax.swing.UIManager;
+import javax.swing.table.TableCellRenderer;
 
+import com.eteks.sweethome3d.io.ContentRecording;
 import com.eteks.sweethome3d.j3d.Component3DManager;
 import com.eteks.sweethome3d.j3d.ModelManager;
 import com.eteks.sweethome3d.j3d.TextureManager;
@@ -66,19 +70,25 @@ import com.eteks.sweethome3d.model.CollectionEvent;
 import com.eteks.sweethome3d.model.CollectionListener;
 import com.eteks.sweethome3d.model.Home;
 import com.eteks.sweethome3d.model.HomeApplication;
+import com.eteks.sweethome3d.model.HomeFurnitureGroup;
+import com.eteks.sweethome3d.model.HomePieceOfFurniture;
 import com.eteks.sweethome3d.model.HomeRecorder;
 import com.eteks.sweethome3d.model.UserPreferences;
 import com.eteks.sweethome3d.plugin.PluginAction;
 import com.eteks.sweethome3d.plugin.PluginManager;
 import com.eteks.sweethome3d.swing.ControllerAction;
+import com.eteks.sweethome3d.swing.FurnitureTable;
 import com.eteks.sweethome3d.swing.IconManager;
 import com.eteks.sweethome3d.swing.ResourceAction;
 import com.eteks.sweethome3d.swing.SwingTools;
 import com.eteks.sweethome3d.swing.SwingViewFactory;
 import com.eteks.sweethome3d.tools.OperatingSystem;
+import com.eteks.sweethome3d.tools.URLContent;
 import com.eteks.sweethome3d.viewcontroller.ContentManager;
+import com.eteks.sweethome3d.viewcontroller.FurnitureController;
 import com.eteks.sweethome3d.viewcontroller.HomeController;
 import com.eteks.sweethome3d.viewcontroller.HomeView;
+import com.eteks.sweethome3d.viewcontroller.View;
 import com.eteks.sweethome3d.viewcontroller.ViewFactory;
 
 /**
@@ -92,12 +102,15 @@ public class AppletApplication extends HomeApplication {
   private static final String TEXTURES_RESOURCES_URL_BASE_PARAMETER  = "texturesResourcesURLBase";
   private static final String PLUGIN_URLS_PARAMETER                  = "pluginURLs";
   private static final String WRITE_HOME_URL_PARAMETER               = "writeHomeURL";
+  private static final String HOME_MAXIMUM_LENGTH                    = "homeMaximumLength";
   private static final String READ_HOME_URL_PARAMETER                = "readHomeURL";
+  private static final String DELETE_HOME_URL_PARAMETER              = "deleteHomeURL";
   private static final String LIST_HOMES_URL_PARAMETER               = "listHomesURL";
   private static final String READ_PREFERENCES_URL_PARAMETER         = "readPreferencesURL";
   private static final String WRITE_PREFERENCES_URL_PARAMETER        = "writePreferencesURL";
   private static final String DEFAULT_HOME_PARAMETER                 = "defaultHome";
   private static final String ENABLE_EXPORT_TO_SH3D                  = "enableExportToSH3D";
+  private static final String ENABLE_IMPORT_FROM_SH3D                = "enableImportFromSH3D";
   private static final String ENABLE_EXPORT_TO_CSV                   = "enableExportToCSV";
   private static final String ENABLE_EXPORT_TO_SVG                   = "enableExportToSVG";
   private static final String ENABLE_EXPORT_TO_OBJ                   = "enableExportToOBJ";
@@ -321,10 +334,10 @@ public class AppletApplication extends HomeApplication {
    * Returns a new instance of a home controller after <code>home</code> was created.
    */
   protected HomeController createHomeController(Home home) {
-    final String writeHomeURL = getAppletParameter(applet, WRITE_HOME_URL_PARAMETER, "writeHome.php");    
-    final String readHomeURL = getAppletParameter(applet, READ_HOME_URL_PARAMETER, "readHome.php?home=%s");
-    final String listHomesURL = getAppletParameter(applet, LIST_HOMES_URL_PARAMETER, "listHomes.php");
-    final String defaultHome = getAppletParameter(applet, DEFAULT_HOME_PARAMETER, "");    
+    final String writeHomeURL = getAppletParameter(this.applet, WRITE_HOME_URL_PARAMETER, "writeHome.php");    
+    final String readHomeURL = getAppletParameter(this.applet, READ_HOME_URL_PARAMETER, "readHome.php?home=%s");
+    final String listHomesURL = getAppletParameter(this.applet, LIST_HOMES_URL_PARAMETER, "listHomes.php");
+    final String defaultHome = getAppletParameter(this.applet, DEFAULT_HOME_PARAMETER, "");    
     
     // Create a home controller for new home
     boolean newHomeEnabled = 
@@ -335,10 +348,11 @@ public class AppletApplication extends HomeApplication {
         && (defaultHome.length() != 0 || listHomesURL.length() != 0);
     boolean saveAsEnabled = 
         writeHomeURL.length() != 0 && listHomesURL.length() != 0;
+    long homeMaximumLength = Long.valueOf(getAppletParameter(applet, HOME_MAXIMUM_LENGTH, "-1"));    
     
     final HomeController controller = new HomeAppletController(
         home, AppletApplication.this, getViewFactory(), getContentManager(), getPluginManager(),
-        newHomeEnabled, openEnabled, saveEnabled, saveAsEnabled);
+        newHomeEnabled, openEnabled, saveEnabled, saveAsEnabled, homeMaximumLength);
     
     JRootPane homeView = (JRootPane)controller.getView();
     // Remove menu bar
@@ -387,6 +401,17 @@ public class AppletApplication extends HomeApplication {
         ex.printStackTrace();
       }
     }
+    if (getAppletBooleanParameter(this.applet, ENABLE_IMPORT_FROM_SH3D)) {
+      try {
+        // Add import from SH3D action
+        Action importFromSH3DAction = new ControllerAction(getUserPreferences(), 
+            AppletApplication.class, "IMPORT_FROM_SH3D", controller, "importFromSH3D");
+        importFromSH3DAction.setEnabled(true);
+        addActionToToolBar(new ResourceAction.ToolBarAction(importFromSH3DAction), toolBar);
+      } catch (NoSuchMethodException ex) {
+        ex.printStackTrace();
+      }
+    }
     
     if (toolBar.getComponentCount() > 0) {
       toolBar.add(Box.createRigidArea(new Dimension(2, 2)));
@@ -584,9 +609,12 @@ public class AppletApplication extends HomeApplication {
       final String writeHomeURL = getAppletParameter(this.applet, WRITE_HOME_URL_PARAMETER, "writeHome.php");    
       final String readHomeURL = getAppletParameter(this.applet, READ_HOME_URL_PARAMETER, "readHome.php?home=%s");
       final String listHomesURL = getAppletParameter(this.applet, LIST_HOMES_URL_PARAMETER, "listHomes.php");
+      final String deleteHomeURL = getAppletParameter(this.applet, DELETE_HOME_URL_PARAMETER, "");
       this.homeRecorder =  new HomeAppletRecorder(getURLStringWithCodeBase(codeBase, writeHomeURL), 
           getURLStringWithCodeBase(codeBase, readHomeURL), 
-          getURLStringWithCodeBase(codeBase, listHomesURL));
+          getURLStringWithCodeBase(codeBase, listHomesURL),
+          getURLStringWithCodeBase(codeBase, deleteHomeURL),
+          ContentRecording.INCLUDE_TEMPORARY_CONTENT);
     }
     return this.homeRecorder;
   }
@@ -628,7 +656,7 @@ public class AppletApplication extends HomeApplication {
    */
   protected ContentManager getContentManager() {
     if (this.contentManager == null) {
-      this.contentManager = new AppletContentManager(getHomeRecorder(), getUserPreferences());
+      this.contentManager = new AppletContentManager(getHomeRecorder(), getUserPreferences(), getViewFactory());
     }
     return this.contentManager;
   }
@@ -638,7 +666,12 @@ public class AppletApplication extends HomeApplication {
    */
   protected ViewFactory getViewFactory() {
     if (this.viewFactory == null) {
-     this.viewFactory = new SwingViewFactory();
+     this.viewFactory = new SwingViewFactory() {
+         @Override
+         public View createFurnitureView(Home home, UserPreferences preferences, FurnitureController furnitureController) {
+           return new AppletFurnitureTable(home, preferences, furnitureController);
+         }
+       };
     }
     return this.viewFactory;
   }
@@ -754,6 +787,49 @@ public class AppletApplication extends HomeApplication {
     }
   }
 
+  /**
+   * A furniture table that renders in italic the name of the imported furniture.
+   */
+  private static final class AppletFurnitureTable extends FurnitureTable {
+    private TableCellRenderer nameRenderer = new TableCellRenderer() {
+        private Font defaultFont;
+        private Font importedPieceFont;
+      
+        public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus,
+                                                       int row, int column) {
+          JComponent rendererComponent = (JComponent)AppletFurnitureTable.super.getCellRenderer(row, column).
+              getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
+          // Initialize fonts if not done
+          if (this.defaultFont == null) {
+            this.defaultFont = table.getFont();
+            this.importedPieceFont = 
+                new Font(this.defaultFont.getFontName(), Font.ITALIC, this.defaultFont.getSize());        
+          }
+          
+          HomePieceOfFurniture piece = (HomePieceOfFurniture)getValueAt(row, column);
+          URLContent model = (URLContent)piece.getModel();
+          // Imported pieces are not stored in URLContent instances
+          boolean importedPiece = model.getClass() != URLContent.class;
+          rendererComponent.setFont(importedPiece  ? this.importedPieceFont  : this.defaultFont);
+          return rendererComponent;
+        }
+      };
+
+    private AppletFurnitureTable(Home home, UserPreferences preferences, FurnitureController controller) {
+      super(home, preferences, controller);
+    }
+
+    @Override
+    public TableCellRenderer getCellRenderer(int row, int column) {
+      if (getColumnModel().getColumn(column).getIdentifier() == HomePieceOfFurniture.SortableProperty.NAME
+          && !(getValueAt(row, column) instanceof HomeFurnitureGroup)) {
+        return this.nameRenderer;
+      } else {
+        return super.getCellRenderer(row, column);
+      }
+    }
+  }
+
   /**
    * JNLP <code>ServiceManagerStub</code> implementation for applets 
    * run out of Java Web Start. This service manager supports <code>BasicService</code> only.
