@@ -49,8 +49,10 @@ import com.eteks.sweethome3d.model.CatalogTexture;
 import com.eteks.sweethome3d.model.FurnitureCatalog;
 import com.eteks.sweethome3d.model.FurnitureCategory;
 import com.eteks.sweethome3d.model.LengthUnit;
+import com.eteks.sweethome3d.model.Library;
 import com.eteks.sweethome3d.model.PatternsCatalog;
 import com.eteks.sweethome3d.model.RecorderException;
+import com.eteks.sweethome3d.model.TextureImage;
 import com.eteks.sweethome3d.model.TexturesCatalog;
 import com.eteks.sweethome3d.model.TexturesCategory;
 import com.eteks.sweethome3d.model.UserPreferences;
@@ -60,31 +62,34 @@ import com.eteks.sweethome3d.model.UserPreferences;
  * @author Emmanuel Puybaret
  */
 public class AppletUserPreferences extends UserPreferences {
-  private static final String LANGUAGE                         = "language";
-  private static final String UNIT                             = "unit";
-  private static final String FURNITURE_CATALOG_VIEWED_IN_TREE = "furnitureCatalogViewedInTree";
-  private static final String NAVIGATION_PANEL_VISIBLE         = "navigationPanelVisible";
-  private static final String MAGNETISM_ENABLED                = "magnetismEnabled";
-  private static final String RULERS_VISIBLE                   = "rulersVisible";
-  private static final String GRID_VISIBLE                     = "gridVisible";
-  private static final String FURNITURE_VIEWED_FROM_TOP        = "furnitureViewedFromTop";
-  private static final String ROOM_FLOOR_COLORED_OR_TEXTURED   = "roomFloorColoredOrTextured";
-  private static final String WALL_PATTERN                     = "wallPattern";
-  private static final String NEW_WALL_HEIGHT                  = "newHomeWallHeight";
-  private static final String NEW_WALL_THICKNESS               = "newWallThickness";
-  private static final String NEW_FLOOR_THICKNESS              = "newFloorThickness";
-  private static final String RECENT_HOMES                     = "recentHomes#";
-  private static final String IGNORED_ACTION_TIP               = "ignoredActionTip#";
+  private static final String LANGUAGE                                  = "language";
+  private static final String UNIT                                      = "unit";
+  private static final String FURNITURE_CATALOG_VIEWED_IN_TREE          = "furnitureCatalogViewedInTree";
+  private static final String NAVIGATION_PANEL_VISIBLE                  = "navigationPanelVisible";
+  private static final String AERIAL_VIEW_CENTERED_ON_SELECTION_ENABLED = "aerialViewCenteredOnSelectionEnabled";
+  private static final String MAGNETISM_ENABLED                         = "magnetismEnabled";
+  private static final String RULERS_VISIBLE                            = "rulersVisible";
+  private static final String GRID_VISIBLE                              = "gridVisible";
+  private static final String FURNITURE_VIEWED_FROM_TOP                 = "furnitureViewedFromTop";
+  private static final String ROOM_FLOOR_COLORED_OR_TEXTURED            = "roomFloorColoredOrTextured";
+  private static final String WALL_PATTERN                              = "wallPattern";
+  private static final String NEW_WALL_PATTERN                          = "newWallPattern";
+  private static final String NEW_WALL_HEIGHT                           = "newHomeWallHeight";
+  private static final String NEW_WALL_THICKNESS                        = "newWallThickness";
+  private static final String NEW_FLOOR_THICKNESS                       = "newFloorThickness";
+  private static final String RECENT_HOMES                              = "recentHomes#";
+  private static final String IGNORED_ACTION_TIP                        = "ignoredActionTip#";
 
-  private final URL [] pluginFurnitureCatalogURLs;
-  private final URL    furnitureResourcesUrlBase;
-  private final URL [] pluginTexturesCatalogURLs;
-  private final URL    texturesResourcesUrlBase;
-  private Properties   properties;
-  private final URL    writePreferencesURL;
-  private final URL    readPreferencesURL;
-  private Executor     catalogsLoader;
-  private Executor     updater;
+  private final URL []  pluginFurnitureCatalogURLs;
+  private final URL     furnitureResourcesUrlBase;
+  private final URL []  pluginTexturesCatalogURLs;
+  private final URL     texturesResourcesUrlBase;
+  private Properties    properties;
+  private final URL     writePreferencesURL;
+  private final URL     readPreferencesURL;
+  private Executor      catalogsLoader;
+  private Executor      updater;
+  private boolean       writtenPropertiesUpdated;
   
   private final Map<String, Boolean> ignoredActionTips = new HashMap<String, Boolean>();
 
@@ -221,6 +226,8 @@ public class AppletUserPreferences extends UserPreferences {
         String.valueOf(defaultPreferences.isFurnitureCatalogViewedInTree()))));
     setNavigationPanelVisible(Boolean.parseBoolean(properties.getProperty(NAVIGATION_PANEL_VISIBLE, 
         String.valueOf(defaultPreferences.isNavigationPanelVisible()))));
+    setAerialViewCenteredOnSelectionEnabled(Boolean.parseBoolean(properties.getProperty(AERIAL_VIEW_CENTERED_ON_SELECTION_ENABLED, 
+        String.valueOf(defaultPreferences.isAerialViewCenteredOnSelectionEnabled()))));
     setMagnetismEnabled(Boolean.parseBoolean(properties.getProperty(MAGNETISM_ENABLED, "true")));
     setRulersVisible(Boolean.parseBoolean(properties.getProperty(RULERS_VISIBLE, 
         String.valueOf(defaultPreferences.isMagnetismEnabled()))));
@@ -237,6 +244,14 @@ public class AppletUserPreferences extends UserPreferences {
       // Ensure wall pattern always exists even if new patterns are added in future versions
       setWallPattern(defaultPreferences.getWallPattern());
     }
+    try {
+      if (defaultPreferences.getNewWallPattern() != null) {
+        setNewWallPattern(patternsCatalog.getPattern(properties.getProperty(NEW_WALL_PATTERN, 
+            defaultPreferences.getNewWallPattern().getName())));
+      }
+    } catch (IllegalArgumentException ex) {
+      // Keep new wall pattern unchanged
+    }
     setNewWallThickness(Float.parseFloat(properties.getProperty(NEW_WALL_THICKNESS, 
             String.valueOf(defaultPreferences.getNewWallThickness()))));
     setNewWallHeight(Float.parseFloat(properties.getProperty(NEW_WALL_HEIGHT,
@@ -268,6 +283,34 @@ public class AppletUserPreferences extends UserPreferences {
           updateDefaultCatalogs();
         }
       });
+    
+    // Add a listener to track written properties and ignore the other ones during a call to write 
+    PropertyChangeListener savedPropertyListener = new PropertyChangeListener() {
+        public void propertyChange(PropertyChangeEvent ev) {
+          writtenPropertiesUpdated = true;
+        }
+      };
+    Property [] writtenProperties = {
+        Property.LANGUAGE,
+        Property.UNIT,
+        Property.FURNITURE_CATALOG_VIEWED_IN_TREE,
+        Property.NAVIGATION_PANEL_VISIBLE,
+        Property.AERIAL_VIEW_CENTERED_ON_SELECTION_ENABLED,
+        Property.MAGNETISM_ENABLED,
+        Property.RULERS_VISIBLE,
+        Property.GRID_VISIBLE,
+        Property.FURNITURE_VIEWED_FROM_TOP,
+        Property.ROOM_FLOOR_COLORED_OR_TEXTURED,
+        Property.WALL_PATTERN,
+        Property.NEW_WALL_PATTERN,
+        Property.NEW_WALL_THICKNESS,
+        Property.NEW_WALL_HEIGHT,
+        Property.NEW_FLOOR_THICKNESS,
+        Property.RECENT_HOMES,
+        Property.IGNORED_ACTION_TIP};
+    for (Property writtenProperty : writtenProperties) {
+      addPropertyChangeListener(writtenProperty, savedPropertyListener);
+    }
   }
 
   /**
@@ -286,7 +329,7 @@ public class AppletUserPreferences extends UserPreferences {
     // Add default pieces 
     this.catalogsLoader.execute(new Runnable() {
         public void run() {
-          FurnitureCatalog defaultFurnitureCatalog = 
+          final DefaultFurnitureCatalog defaultFurnitureCatalog = 
               new DefaultFurnitureCatalog(pluginFurnitureCatalogURLs, furnitureResourcesUrlBase);
           for (final FurnitureCategory category : defaultFurnitureCatalog.getCategories()) {
             for (final CatalogPieceOfFurniture piece : category.getFurniture()) {
@@ -312,7 +355,7 @@ public class AppletUserPreferences extends UserPreferences {
     // Add default textures
     this.catalogsLoader.execute(new Runnable() {
         public void run() {
-          TexturesCatalog defaultTexturesCatalog = 
+          final DefaultTexturesCatalog defaultTexturesCatalog = 
               new DefaultTexturesCatalog(pluginTexturesCatalogURLs, texturesResourcesUrlBase);
           for (final TexturesCategory category : defaultTexturesCatalog.getCategories()) {
             for (final CatalogTexture texture : category.getTextures()) {
@@ -333,43 +376,53 @@ public class AppletUserPreferences extends UserPreferences {
    */
   @Override
   public void write() throws RecorderException {
-    Properties properties = getProperties();
-    // Write other preferences 
-    properties.setProperty(LANGUAGE, getLanguage());
-    properties.setProperty(UNIT, getLengthUnit().name());   
-    properties.setProperty(FURNITURE_CATALOG_VIEWED_IN_TREE, String.valueOf(isFurnitureCatalogViewedInTree()));
-    properties.setProperty(NAVIGATION_PANEL_VISIBLE, String.valueOf(isNavigationPanelVisible()));    
-    properties.setProperty(MAGNETISM_ENABLED, String.valueOf(isMagnetismEnabled()));
-    properties.setProperty(RULERS_VISIBLE, String.valueOf(isRulersVisible()));
-    properties.setProperty(GRID_VISIBLE, String.valueOf(isGridVisible()));
-    properties.setProperty(FURNITURE_VIEWED_FROM_TOP, String.valueOf(isFurnitureViewedFromTop()));
-    properties.setProperty(ROOM_FLOOR_COLORED_OR_TEXTURED, String.valueOf(isRoomFloorColoredOrTextured()));
-    properties.setProperty(WALL_PATTERN, getWallPattern().getName());
-    properties.setProperty(NEW_WALL_THICKNESS, String.valueOf(getNewWallThickness()));   
-    properties.setProperty(NEW_WALL_HEIGHT, String.valueOf(getNewWallHeight()));
-    properties.setProperty(NEW_FLOOR_THICKNESS, String.valueOf(getNewFloorThickness()));   
-    // Write recent homes list
-    int i = 1;
-    for (Iterator<String> it = getRecentHomes().iterator(); it.hasNext() && i <= getRecentHomesMaxCount(); i ++) {
-      properties.setProperty(RECENT_HOMES + i, it.next());
-    }
-    // Write ignored action tips
-    i = 1;
-    for (Iterator<Map.Entry<String, Boolean>> it = this.ignoredActionTips.entrySet().iterator();
-         it.hasNext(); ) {
-      Entry<String, Boolean> ignoredActionTipEntry = it.next();
-      if (ignoredActionTipEntry.getValue()) {
-        properties.setProperty(IGNORED_ACTION_TIP + i++, ignoredActionTipEntry.getKey());
-      } 
-    }
-    
-    try {
-      // Write preferences 
-      if (this.writePreferencesURL != null) {
-        writePreferences(getProperties());
+    if (this.writtenPropertiesUpdated) {
+      // Write actually preferences only if written properties were updated
+      this.writtenPropertiesUpdated = false;
+      
+      Properties properties = getProperties();
+      // Write other preferences 
+      properties.setProperty(LANGUAGE, getLanguage());
+      properties.setProperty(UNIT, getLengthUnit().name());   
+      properties.setProperty(FURNITURE_CATALOG_VIEWED_IN_TREE, String.valueOf(isFurnitureCatalogViewedInTree()));
+      properties.setProperty(NAVIGATION_PANEL_VISIBLE, String.valueOf(isNavigationPanelVisible()));    
+      properties.setProperty(AERIAL_VIEW_CENTERED_ON_SELECTION_ENABLED, String.valueOf(isAerialViewCenteredOnSelectionEnabled()));    
+      properties.setProperty(MAGNETISM_ENABLED, String.valueOf(isMagnetismEnabled()));
+      properties.setProperty(RULERS_VISIBLE, String.valueOf(isRulersVisible()));
+      properties.setProperty(GRID_VISIBLE, String.valueOf(isGridVisible()));
+      properties.setProperty(FURNITURE_VIEWED_FROM_TOP, String.valueOf(isFurnitureViewedFromTop()));
+      properties.setProperty(ROOM_FLOOR_COLORED_OR_TEXTURED, String.valueOf(isRoomFloorColoredOrTextured()));
+      properties.setProperty(WALL_PATTERN, getWallPattern().getName());
+      TextureImage newWallPattern = getNewWallPattern();
+      if (newWallPattern != null) {
+        properties.setProperty(NEW_WALL_PATTERN, newWallPattern.getName());
+      }
+      properties.setProperty(NEW_WALL_THICKNESS, String.valueOf(getNewWallThickness()));   
+      properties.setProperty(NEW_WALL_HEIGHT, String.valueOf(getNewWallHeight()));
+      properties.setProperty(NEW_FLOOR_THICKNESS, String.valueOf(getNewFloorThickness()));   
+      // Write recent homes list
+      int i = 1;
+      for (Iterator<String> it = getRecentHomes().iterator(); it.hasNext() && i <= getRecentHomesMaxCount(); i ++) {
+        properties.setProperty(RECENT_HOMES + i, it.next());
+      }
+      // Write ignored action tips
+      i = 1;
+      for (Iterator<Map.Entry<String, Boolean>> it = this.ignoredActionTips.entrySet().iterator();
+          it.hasNext(); ) {
+        Entry<String, Boolean> ignoredActionTipEntry = it.next();
+        if (ignoredActionTipEntry.getValue()) {
+          properties.setProperty(IGNORED_ACTION_TIP + i++, ignoredActionTipEntry.getKey());
+        } 
+      }
+      
+      try {
+        // Write preferences 
+        if (this.writePreferencesURL != null) {
+          writePreferences(getProperties());
+        }
+      } catch (IOException ex) {
+        throw new RecorderException("Couldn't write preferences", ex);
       }
-    } catch (IOException ex) {
-      throw new RecorderException("Couldn't write preferences", ex);
     }
   }
 
@@ -483,47 +536,56 @@ public class AppletUserPreferences extends UserPreferences {
    * Throws an exception because applet user preferences can't manage language libraries.
    */
   @Override
-  public void addLanguageLibrary(String languageLibraryName) throws RecorderException {
-    throw new RecorderException("No language libraries");
+  public void addLanguageLibrary(String location) throws RecorderException {
+    throw new UnsupportedOperationException();
   }
 
   /**
    * Throws an exception because applet user preferences can't manage additional language libraries.
    */
   @Override
-  public boolean languageLibraryExists(String languageLibraryName) throws RecorderException {
-    throw new RecorderException("No language libraries");
+  public boolean languageLibraryExists(String location) throws RecorderException {
+    throw new UnsupportedOperationException();
   }
 
   /**
-   * Throws an exception because applet user preferences can't manage furniture libraries.
+   * Returns <code>true</code> if the furniture library at the given <code>location</code> exists.
    */
   @Override
-  public boolean furnitureLibraryExists(String name) throws RecorderException {
-    throw new RecorderException("No furniture libraries");
+  public boolean furnitureLibraryExists(String location) throws RecorderException {
+    throw new UnsupportedOperationException();
   }
 
   /**
    * Throws an exception because applet user preferences can't manage additional furniture libraries.
    */
   @Override
-  public void addFurnitureLibrary(String name) throws RecorderException {
-    throw new RecorderException("No furniture libraries");
+  public void addFurnitureLibrary(String location) throws RecorderException {
+    throw new UnsupportedOperationException();
   }
 
   /**
-   * Throws an exception because applet user preferences can't manage textures libraries.
+   * Returns <code>true</code> if the textures library at the given <code>location</code> exists.
    */
   @Override
-  public boolean texturesLibraryExists(String name) throws RecorderException {
-    throw new RecorderException("No textures libraries");
+  public boolean texturesLibraryExists(String location) throws RecorderException {
+    throw new UnsupportedOperationException();
   }
 
   /**
    * Throws an exception because applet user preferences can't manage additional textures libraries.
    */
   @Override
-  public void addTexturesLibrary(String name) throws RecorderException {
-    throw new RecorderException("No textures libraries");
+  public void addTexturesLibrary(String location) throws RecorderException {
+    throw new UnsupportedOperationException();
+  }
+
+
+  /**
+   * Throws an exception because applet user preferences don't manage additional libraries.
+   */
+  @Override
+  public List<Library> getLibraries() {
+    throw new UnsupportedOperationException();
   }
 }
