@@ -19,10 +19,13 @@
  */
 package com.eteks.sweethome3d.j3d;
 
+import java.awt.Graphics;
 import java.awt.GraphicsConfigTemplate;
 import java.awt.GraphicsConfiguration;
 import java.awt.GraphicsDevice;
 import java.awt.GraphicsEnvironment;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
 import java.awt.image.BufferedImage;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
@@ -36,7 +39,9 @@ import javax.media.j3d.RenderingErrorListener;
 import javax.media.j3d.Screen3D;
 import javax.media.j3d.View;
 import javax.media.j3d.VirtualUniverse;
+import javax.swing.Timer;
 
+import com.eteks.sweethome3d.tools.OperatingSystem;
 import com.sun.j3d.utils.universe.SimpleUniverse;
 import com.sun.j3d.utils.universe.Viewer;
 import com.sun.j3d.utils.universe.ViewingPlatform;
@@ -190,12 +195,16 @@ public class Component3DManager {
     try {
       // Ensure unused canvases are freed
       System.gc();
+      
       // Create a Java 3D canvas  
+      final Canvas3D canvas3D;
       if (renderingObserver != null) {
-        return new ObservedCanvas3D(configuration, offscreen, renderingObserver);
+        canvas3D = new ObservedCanvas3D(configuration, offscreen, renderingObserver);
       } else {
-        return new Canvas3D(configuration, offscreen);
+        canvas3D = new Canvas3D(configuration, offscreen);
       }
+      
+      return canvas3D;
     } catch (IllegalArgumentException ex) {
       IllegalRenderingStateException ex2 = new IllegalRenderingStateException("Can't create Canvas 3D");
       ex2.initCause(ex);
@@ -363,12 +372,18 @@ public class Component3DManager {
    */
   private static class ObservedCanvas3D extends Canvas3D {
     private final RenderingObserver renderingObserver;
+    private final boolean           paintDelayed;
+    private Timer timer;
 
     private ObservedCanvas3D(GraphicsConfiguration graphicsConfiguration, 
                              boolean offScreen,
                              RenderingObserver renderingObserver) {
       super(graphicsConfiguration, offScreen);
       this.renderingObserver = renderingObserver;
+      // Under Windows with Java 7 and above, delay the rendering of the canvas 3D when 
+      // it's repainted (i.e. it's resized, moved or partially hidden) to avoid it to get grayed
+      this.paintDelayed = OperatingSystem.isWindows() 
+          && OperatingSystem.isJavaVersionGreaterOrEqual("1.7");
     }
 
     @Override
@@ -385,5 +400,23 @@ public class Component3DManager {
     public void postSwap() {
       this.renderingObserver.canvas3DSwapped(this);
     }
+    
+    @Override
+    public void paint(Graphics g) {
+      if (this.paintDelayed) {
+        if (this.timer == null) {
+          this.timer = new Timer(100, new ActionListener() {
+              public void actionPerformed(ActionEvent ev) {
+                // Graphics parameter isn't actually used by Canvas3D class
+                ObservedCanvas3D.super.paint(null);
+              }
+            });
+          this.timer.setRepeats(false);            
+        }
+        this.timer.restart();
+      } else {
+        super.paint(g);
+      }
+    }
   }
 }
