@@ -34,6 +34,7 @@ import javax.media.j3d.Appearance;
 import javax.media.j3d.Shape3D;
 import javax.media.j3d.Texture;
 import javax.media.j3d.TextureAttributes;
+import javax.media.j3d.TransparencyAttributes;
 import javax.vecmath.Point3f;
 import javax.vecmath.TexCoord2f;
 
@@ -77,6 +78,10 @@ public class Ground3D extends Object3DBranch {
     TextureAttributes textureAttributes = new TextureAttributes();
     textureAttributes.setTextureMode(TextureAttributes.MODULATE);
     groundAppearance.setTextureAttributes(textureAttributes);
+    groundAppearance.setCapability(Appearance.ALLOW_TRANSPARENCY_ATTRIBUTES_READ);
+    TransparencyAttributes transparencyAttributes = new TransparencyAttributes();
+    transparencyAttributes.setCapability(TransparencyAttributes.ALLOW_MODE_WRITE);
+    groundAppearance.setTransparencyAttributes(transparencyAttributes);
 
     final Shape3D groundShape = new Shape3D();
     groundShape.setAppearance(groundAppearance);
@@ -113,13 +118,19 @@ public class Ground3D extends Object3DBranch {
       int groundColor = home.getEnvironment().getGroundColor();
       groundAppearance.setMaterial(getMaterial(groundColor, groundColor, 0));
       groundAppearance.setTexture(null);
+      groundAppearance.getTransparencyAttributes().setTransparencyMode(TransparencyAttributes.NONE);      
     } else {
       groundAppearance.setMaterial(getMaterial(DEFAULT_COLOR, DEFAULT_COLOR, 0));
       final TextureManager imageManager = TextureManager.getInstance();
-      imageManager.loadTexture(groundTexture.getImage(), waitTextureLoadingEnd,
+      imageManager.loadTexture(groundTexture.getImage(), groundTexture.getAngle(), waitTextureLoadingEnd,
           new TextureManager.TextureObserver() {
               public void textureUpdated(Texture texture) {
                 groundAppearance.setTexture(getHomeTextureClone(texture, home));
+                TransparencyAttributes transparencyAttributes = groundAppearance.getTransparencyAttributes();
+                // If texture isn't transparent, turn off transparency  
+                transparencyAttributes.setTransparencyMode(TextureManager.getInstance().isTextureTransparent(texture) 
+                    ? TransparencyAttributes.NICEST
+                    : TransparencyAttributes.NONE);      
               }
             });
     }
@@ -328,14 +339,23 @@ public class Ground3D extends Object3DBranch {
           ? new TexCoord2f [vertexCount]
           : null;
       
+      float textureWidth;
+      float textureHeight;
+      if (groundTexture != null) {
+        textureWidth = TextureManager.getInstance().getRotatedTextureWidth(groundTexture);
+        textureHeight = TextureManager.getInstance().getRotatedTextureHeight(groundTexture);
+      } else {
+        textureWidth = 0;
+        textureHeight = 0;
+      }
       int j = 0;
       for (float [][] areaPartPoints : areaPoints) {
         for (int i = 0; i < areaPartPoints.length; i++, j++) {
           float [] point = areaPartPoints [i];
           geometryCoords [j] = new Point3f(point [0], elevation, point [1]);
           if (groundTexture != null) {
-            geometryTextureCoords [j] = new TexCoord2f((point [0] - this.originX) / groundTexture.getWidth(), 
-                (this.originY - point [1]) / groundTexture.getHeight());
+            geometryTextureCoords [j] = new TexCoord2f((point [0] - this.originX) / textureWidth, 
+                (this.originY - point [1]) / textureHeight);
           }
         }
       }
@@ -364,6 +384,15 @@ public class Ground3D extends Object3DBranch {
     TexCoord2f [] geometryTextureCoords = groundTexture != null 
         ? new TexCoord2f [geometryCoords.length]
         : null;
+    float textureWidth;
+    float textureHeight;
+    if (groundTexture != null) {
+      textureWidth = TextureManager.getInstance().getRotatedTextureWidth(groundTexture);
+      textureHeight = TextureManager.getInstance().getRotatedTextureHeight(groundTexture);
+    } else {
+      textureWidth = 0;
+      textureHeight = 0;
+    }
     for (int i = 0, j = 0; i < areaPoints.length; i++) {
       float [] point = areaPoints [i];
       float [] nextPoint = areaPoints [i < areaPoints.length - 1 ? i + 1 : 0];
@@ -373,10 +402,10 @@ public class Ground3D extends Object3DBranch {
       geometryCoords [j++] = new Point3f(nextPoint [0], elevation, nextPoint [1]);
       if (groundTexture != null) {
         float distance = (float)Point2D.distance(point [0], point [1], nextPoint [0], nextPoint [1]);
-        geometryTextureCoords [j - 4] = new TexCoord2f(point [0] / groundTexture.getWidth(), elevation / groundTexture.getHeight());
-        geometryTextureCoords [j - 3] = new TexCoord2f(point [0] / groundTexture.getWidth(), (elevation + sideHeight) / groundTexture.getHeight());
-        geometryTextureCoords [j - 2] = new TexCoord2f((point [0] - distance) / groundTexture.getWidth(), (elevation + sideHeight) / groundTexture.getHeight());
-        geometryTextureCoords [j - 1] = new TexCoord2f((point [0] - distance) / groundTexture.getWidth(), elevation / groundTexture.getHeight());
+        geometryTextureCoords [j - 4] = new TexCoord2f(point [0] / textureWidth, elevation / textureHeight);
+        geometryTextureCoords [j - 3] = new TexCoord2f(point [0] / textureWidth, (elevation + sideHeight) / textureHeight);
+        geometryTextureCoords [j - 2] = new TexCoord2f((point [0] - distance) / textureWidth, (elevation + sideHeight) / textureHeight);
+        geometryTextureCoords [j - 1] = new TexCoord2f((point [0] - distance) / textureWidth, elevation / textureHeight);
       }
     }
 
