@@ -693,12 +693,14 @@ public class Wall3D extends Object3DBranch {
     if (texture != null) {
       float halfThicknessSq = (wall.getThickness() * wall.getThickness()) / 4;
       TexCoord2f [] textureCoords = new TexCoord2f [coords.size()];
-      float minElevationTextureCoords = minElevation / texture.getHeight();
+      float textureWidth = TextureManager.getInstance().getRotatedTextureWidth(texture);
+      float textureHeight = TextureManager.getInstance().getRotatedTextureHeight(texture);
+      float minElevationTextureCoords = minElevation / textureHeight;
       TexCoord2f firstTextureCoords = new TexCoord2f(0, minElevationTextureCoords);
       int j = 0;
       // Tolerate more error with round walls since arc points are approximative
       float epsilon = arcCircleCenter == null 
-          ? 0.0001f 
+          ? wall.getThickness() / 1E4f 
           : halfThicknessSq / 4;
       for (int index = 0; index < points.length; index++) {
         if (usedRectangle [index]) {
@@ -713,19 +715,19 @@ public class Wall3D extends Object3DBranch {
             float secondHorizontalTextureCoords;
             if (arcCircleCenter == null) {
               firstHorizontalTextureCoords = (float)Point2D.distance(textureReferencePoint[0], textureReferencePoint[1], 
-                  points [index][0], points [index][1]) / texture.getWidth();
+                  points [index][0], points [index][1]) / textureWidth;
               secondHorizontalTextureCoords = (float)Point2D.distance(textureReferencePoint[0], textureReferencePoint[1], 
-                  points [nextIndex][0], points [nextIndex][1]) / texture.getWidth();
+                  points [nextIndex][0], points [nextIndex][1]) / textureWidth;
             } else {
               if (pointUCoordinates [index] == null) {
                 float pointAngle = (float)Math.atan2(points [index][1] - arcCircleCenter [1], points [index][0] - arcCircleCenter [0]);
                 pointAngle = adjustAngleOnReferencePointAngle(pointAngle, referencePointAngle, arcExtent);
-                pointUCoordinates [index] = (pointAngle - referencePointAngle) * arcCircleRadius / texture.getWidth();
+                pointUCoordinates [index] = (pointAngle - referencePointAngle) * arcCircleRadius / textureWidth;
               }
               if (pointUCoordinates [nextIndex] == null) {
                 float pointAngle = (float)Math.atan2(points [nextIndex][1] - arcCircleCenter [1], points [nextIndex][0] - arcCircleCenter [0]);
                 pointAngle = adjustAngleOnReferencePointAngle(pointAngle, referencePointAngle, arcExtent);
-                pointUCoordinates [nextIndex] = (pointAngle - referencePointAngle) * arcCircleRadius / texture.getWidth();
+                pointUCoordinates [nextIndex] = (pointAngle - referencePointAngle) * arcCircleRadius / textureWidth;
               }
               
               firstHorizontalTextureCoords = pointUCoordinates [index];
@@ -741,7 +743,7 @@ public class Wall3D extends Object3DBranch {
           } else {
             textureCoords1 = firstTextureCoords;
             float horizontalTextureCoords = (float)Point2D.distance(points [index][0], points [index][1], 
-                points [nextIndex][0], points [nextIndex][1]) / texture.getWidth();
+                points [nextIndex][0], points [nextIndex][1]) / textureWidth;
             textureCoords2 = new TexCoord2f(horizontalTextureCoords, minElevationTextureCoords);
           }
           
@@ -750,7 +752,7 @@ public class Wall3D extends Object3DBranch {
             for (float yMax = Math.min(top [index].y, top [nextIndex].y) - subpartSize / 2; y < yMax; y += subpartSize) {
               textureCoords [j++] = textureCoords1;
               textureCoords [j++] = textureCoords2;
-              float yTextureCoords = y / texture.getHeight();
+              float yTextureCoords = y / textureHeight;
               textureCoords1 = new TexCoord2f(textureCoords1.x, yTextureCoords);
               textureCoords2 = new TexCoord2f(textureCoords2.x, yTextureCoords);
               textureCoords [j++] = textureCoords2;
@@ -759,8 +761,8 @@ public class Wall3D extends Object3DBranch {
           }
           textureCoords [j++] = textureCoords1;
           textureCoords [j++] = textureCoords2;
-          textureCoords [j++] = new TexCoord2f(textureCoords2.x, top [nextIndex].y / texture.getHeight());
-          textureCoords [j++] = new TexCoord2f(textureCoords1.x, top [index].y / texture.getHeight());
+          textureCoords [j++] = new TexCoord2f(textureCoords2.x, top [nextIndex].y / textureHeight);
+          textureCoords [j++] = new TexCoord2f(textureCoords1.x, top [index].y / textureHeight);
         }
       }
       geometryInfo.setTextureCoordinateParams(1, 2);
@@ -959,12 +961,18 @@ public class Wall3D extends Object3DBranch {
           List<Point3f> slopingTopCoords = new ArrayList<Point3f>();        
           TexCoord2f [] textureCoords;
           List<TexCoord2f> borderTextureCoords;
+          float textureWidth;
+          float textureHeight;
           if (texture != null) {
             textureCoords = new TexCoord2f [coords.length];
             borderTextureCoords = new ArrayList<TexCoord2f>(4 * vertexCount);
+            textureWidth = TextureManager.getInstance().getRotatedTextureWidth(texture);
+            textureHeight = TextureManager.getInstance().getRotatedTextureHeight(texture);
           } else {
             textureCoords = null;
             borderTextureCoords = null;
+            textureWidth = 0;
+            textureHeight = 0;
           }
           int i = 0;
           for (float [][] areaPoints : doorOrWindowSurroundingAreasPoints) {
@@ -974,11 +982,11 @@ public class Wall3D extends Object3DBranch {
             if (texture != null) {
               // Compute texture coordinates of wall side according to textureReferencePoint
               float horizontalTextureCoords = (float)Point2D.distance(textureReferencePoint[0], textureReferencePoint[1], 
-                  point.x, point.z) / texture.getWidth();
+                  point.x, point.z) / textureWidth;
               if (wallSide == WALL_LEFT_SIDE && texture.isLeftToRightOriented()) {
                 horizontalTextureCoords = -horizontalTextureCoords;
               }
-              textureCoord = new TexCoord2f(horizontalTextureCoords, point.y / texture.getHeight());
+              textureCoord = new TexCoord2f(horizontalTextureCoords, point.y / textureHeight);
             }
             double distanceToTop = Line2D.ptLineDistSq(topWallPoint1.x, topWallPoint1.y, topWallPoint2.x, topWallPoint2.y, 
                 areaPoints [0][0], areaPoints [0][1]);
@@ -1014,11 +1022,11 @@ public class Wall3D extends Object3DBranch {
               TexCoord2f nextTextureCoord = null;
               if (texture != null) {
                 float horizontalTextureCoords = (float)Point2D.distance(textureReferencePoint[0], textureReferencePoint[1], 
-                    nextPoint.x, nextPoint.z) / texture.getWidth();
+                    nextPoint.x, nextPoint.z) / textureWidth;
                 if (wallSide == WALL_LEFT_SIDE && texture.isLeftToRightOriented()) {
                   horizontalTextureCoords = -horizontalTextureCoords;
                 }
-                nextTextureCoord = new TexCoord2f(horizontalTextureCoords, nextPoint.y / texture.getHeight());
+                nextTextureCoord = new TexCoord2f(horizontalTextureCoords, nextPoint.y / textureHeight);
                 if (coordsList == borderCoords) {
                   borderTextureCoords.add(textureCoord);
                   borderTextureCoords.add(textureCoord);
@@ -1200,7 +1208,7 @@ public class Wall3D extends Object3DBranch {
       // Update material and texture of wall side
       wallSideAppearance.setMaterial(getMaterial(DEFAULT_COLOR, DEFAULT_AMBIENT_COLOR, shininess));
       final TextureManager textureManager = TextureManager.getInstance();
-      textureManager.loadTexture(wallSideTexture.getImage(), waitTextureLoadingEnd,
+      textureManager.loadTexture(wallSideTexture.getImage(), wallSideTexture.getAngle(), waitTextureLoadingEnd,
           new TextureManager.TextureObserver() {
               public void textureUpdated(Texture texture) {
                 wallSideAppearance.setTexture(getHomeTextureClone(texture, home));
