@@ -264,13 +264,62 @@ public class CatalogDoorOrWindow extends CatalogPieceOfFurniture implements Door
                              float [][] modelRotation, String creator, 
                              boolean resizable, boolean deformable, boolean texturable, 
                              BigDecimal price, BigDecimal valueAddedTaxPercentage, String currency) {
+    this(id, name, description, information, tags, creationDate, grade, 
+        icon, planIcon, model, width, depth, height, elevation, 1f, movable, 
+        cutOutShape, wallThickness, wallDistance, sashes,
+        modelRotation, creator, resizable, deformable, texturable, price, valueAddedTaxPercentage, currency);
+  }
+         
+  /**
+   * Creates an unmodifiable catalog door or window of the default catalog.
+   * @param id    the id of the new door or window, or <code>null</code>
+   * @param name  the name of the new door or window
+   * @param description the description of the new door or window 
+   * @param information additional information associated to the new door or window
+   * @param tags tags associated to the new door or window
+   * @param creationDate creation date of the new door or window in milliseconds since the epoch 
+   * @param grade grade of the new door or window or <code>null</code>
+   * @param icon content of the icon of the new door or window
+   * @param planIcon content of the icon of the new piece displayed in plan
+   * @param model content of the 3D model of the new door or window
+   * @param width  the width in centimeters of the new door or window
+   * @param depth  the depth in centimeters of the new door or window
+   * @param height  the height in centimeters of the new door or window
+   * @param elevation  the elevation in centimeters of the new door or window
+   * @param dropOnTopElevation a percentage of the height at which should be placed 
+   *            an object dropped on the new piece
+   * @param movable if <code>true</code>, the new door or window is movable
+   * @param cutOutShape the shape used to cut out walls that intersect the new door or window
+   * @param wallThickness a value in percentage of the depth of the new door or window
+   * @param wallDistance a distance in percentage of the depth of the new door or window
+   * @param sashes the sashes attached to the new door or window
+   * @param modelRotation the rotation 3 by 3 matrix applied to the door or window model
+   * @param creator the creator of the model
+   * @param resizable if <code>true</code>, the size of the new door or window may be edited
+   * @param deformable if <code>true</code>, the width, depth and height of the new piece may 
+   *            change independently from each other
+   * @param texturable if <code>false</code> this piece should always keep the same color or texture.
+   * @param price the price of the new door or window, or <code>null</code> 
+   * @param valueAddedTaxPercentage the Value Added Tax percentage applied to the 
+   *             price of the new door or window or <code>null</code>
+   * @param currency the price currency, noted with ISO 4217 code, or <code>null</code> 
+   * @since 4.4 
+   */
+  public CatalogDoorOrWindow(String id, String name, String description, 
+                             String information, String [] tags, Long creationDate, Float grade, 
+                             Content icon, Content planIcon, Content model, 
+                             float width, float depth, float height, float elevation, float dropOnTopElevation, boolean movable, 
+                             String cutOutShape, float wallThickness, float wallDistance, Sash [] sashes,
+                             float [][] modelRotation, String creator, 
+                             boolean resizable, boolean deformable, boolean texturable, 
+                             BigDecimal price, BigDecimal valueAddedTaxPercentage, String currency) {
     super(id, name, description, information, tags, creationDate, grade, 
         icon, planIcon, model, width, depth, height, elevation, movable, 
         null, modelRotation, creator, resizable, deformable, texturable, price, valueAddedTaxPercentage, currency);
+    this.cutOutShape = cutOutShape;
     this.wallThickness = wallThickness;
     this.wallDistance = wallDistance;
     this.sashes = sashes;
-    this. cutOutShape = cutOutShape;
   }
          
   /**
