@@ -854,6 +854,14 @@ public abstract class UserPreferences {
     return 10;
   }
 
+  /**
+   * Returns the maximum count of stored cameras in homes that should be proposed to the user.
+   * @since 4.5
+   */
+  public int getStoredCamerasMaxCount() {
+    return 50;
+  }
+
   /**
    * Sets which action tip should be ignored.
    * <br>This method should be overridden to store the ignore information.
