@@ -35,10 +35,13 @@ import java.awt.print.Paper;
 import java.awt.print.Printable;
 import java.awt.print.PrinterException;
 import java.awt.print.PrinterJob;
+import java.security.AccessControlException;
 import java.text.MessageFormat;
 import java.util.Date;
+import java.util.HashSet;
 import java.util.MissingResourceException;
 import java.util.ResourceBundle;
+import java.util.Set;
 
 import javax.swing.JComponent;
 import javax.swing.JLabel;
@@ -119,6 +122,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
   private final Font           headerFooterFont;
   private int                  page;
   private int                  pageCount = -1;
+  private Set<Integer>         printablePages = new HashSet<Integer>();
   private int                  furniturePageCount;
   private int                  planPageCount;
   private Date                 printDate;
@@ -176,6 +180,22 @@ public class HomePrintableComponent extends JComponent implements Printable {
     g2D.setFont(this.defaultFont);
     g2D.setColor(Color.WHITE);
     g2D.fill(new Rectangle2D.Double(0, 0, pageFormat.getWidth(), pageFormat.getHeight()));
+
+    Paper oldPaper = pageFormat.getPaper();
+    try {
+      // Let the user be able to force a fixed margin in case of bugs in page setup dialogs or printer drivers
+      String fixedPrintMargin = System.getProperty("com.eteks.sweethome3d.swing.fixedPrintMargin", null);
+      if (fixedPrintMargin != null) {
+        float margin = LengthUnit.centimeterToInch(Float.parseFloat(fixedPrintMargin)) * 72;
+        Paper noMarginPaper = pageFormat.getPaper();
+        noMarginPaper.setImageableArea(margin, margin, oldPaper.getWidth() - 2 * margin, oldPaper.getHeight() - 2 * margin);
+        pageFormat.setPaper(noMarginPaper);
+      }
+    } catch (NumberFormatException ex) {
+      ex.printStackTrace();
+    } catch (AccessControlException ex) {
+      // If com.eteks.sweethome3d.swing.fixedPrintMargin can't be read, ignore fixed margin
+    }
     int pageExists = NO_SUCH_PAGE;
     HomePrint homePrint = this.home.getPrint();
     
@@ -210,7 +230,6 @@ public class HomePrintableComponent extends JComponent implements Printable {
     
     Rectangle clipBounds = g2D.getClipBounds();
     AffineTransform oldTransform = g2D.getTransform();
-    Paper oldPaper = pageFormat.getPaper();
     final PlanView planView = this.controller.getPlanController().getView();
     if (homePrint != null
         || this.fixedHeaderLabel != null
@@ -294,6 +313,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
           break;
       }
       pageFormat.setPaper(paper);
+      
       if (clipBounds == null) {
         g2D.clipRect((int)pageFormat.getImageableX(), (int)pageFormat.getImageableY(), 
             (int)pageFormat.getImageableWidth(), (int)pageFormat.getImageableHeight());
@@ -303,10 +323,6 @@ public class HomePrintableComponent extends JComponent implements Printable {
       }
     }
     
-    if (page == 0) {
-      this.furniturePageCount = 0;
-      this.planPageCount = 0;
-    }
     View furnitureView = this.controller.getFurnitureController().getView();
     if (furnitureView != null 
         && (homePrint == null || homePrint.isFurniturePrinted())) {
@@ -335,7 +351,9 @@ public class HomePrintableComponent extends JComponent implements Printable {
         // Restore previous filter
         ((FurnitureTable)furnitureView).setFurnitureFilter(furnitureFilter);
       }
-      if (pageExists == PAGE_EXISTS) {
+      if (pageExists == PAGE_EXISTS
+          && !this.printablePages.contains(page)) {
+        this.printablePages.add(page);
         this.furniturePageCount++;
       }
     }
@@ -344,7 +362,9 @@ public class HomePrintableComponent extends JComponent implements Printable {
         && (homePrint == null || homePrint.isPlanPrinted())) {
       // Try to print next plan view page
       pageExists = ((Printable)planView).print(g2D, pageFormat, page - this.furniturePageCount);
-      if (pageExists == PAGE_EXISTS) {
+      if (pageExists == PAGE_EXISTS
+          && !this.printablePages.contains(page)) {
+        this.printablePages.add(page);
         this.planPageCount++;
       }
     }
@@ -353,6 +373,10 @@ public class HomePrintableComponent extends JComponent implements Printable {
         && view3D != null
         && (homePrint == null || homePrint.isView3DPrinted())) {
       pageExists = ((Printable)view3D).print(g2D, pageFormat, page - this.planPageCount - this.furniturePageCount);
+      if (pageExists == PAGE_EXISTS
+          && !this.printablePages.contains(page)) {
+        this.printablePages.add(page);
+      }
     }
     
     // Print header and footer
