@@ -609,6 +609,12 @@ public class ModelMaterialsComponent extends JButton implements View {
           new ModelManager.ModelObserver() {
             public void modelUpdated(BranchGroup modelRoot) {
               defaultMaterials = ModelManager.getInstance().getMaterials(modelRoot);
+              // If read materials list is larger, ignore previous materials change
+              // (this could be the case if loader interprets differently a 3D model file)
+              if (materials != null
+                  && materials.length < defaultMaterials.length) {
+                materials = null;
+              }
               fireContentsChanged(MaterialsListModel.this, 0, defaultMaterials.length);
             }
 
@@ -620,7 +626,9 @@ public class ModelMaterialsComponent extends JButton implements View {
 
       public Object getElementAt(int index) {
         if (this.materials != null
-            && this.materials [index] != null) {
+            && this.materials [index] != null
+            && this.materials [index].getName() != null
+            && this.materials [index].getName().equals(this.defaultMaterials [index].getName())) {
           return this.materials [index];
         } else {
           return new HomeMaterial(this.defaultMaterials [index].getName(), null, null, null); 
@@ -711,11 +719,13 @@ public class ModelMaterialsComponent extends JButton implements View {
                 if (selectedColor == null) {
                   selectedColor = defaultMaterial.getColor();
                 }
-                int componentAverage = (((selectedColor >> 16) & 0xFF) + ((selectedColor >> 8) & 0xFF) + (selectedColor & 0xFF)) / 3;
-                if (componentAverage > 0x77) {
+                int red   = (selectedColor >> 16) & 0xFF;
+                int green = (selectedColor >> 8) & 0xFF;
+                int blue  = selectedColor & 0xFF;
+                if (Math.max(red, Math.max(green, blue)) > 0x77) {
                   // Display a darker color for a bright color
                   blinkColor = new Color(selectedColor).darker().darker().getRGB();
-                } else if (componentAverage > 0x0F) {
+                } else if ((red + green + blue) / 3 > 0x0F) {
                   // Display a brighter color for a dark color
                   blinkColor = new Color(selectedColor).brighter().brighter().getRGB();
                 }
