@@ -194,7 +194,8 @@ public class TextureChoiceComponent extends JButton implements TextureChoiceView
    */
   private static class TexturePanel extends JPanel {
     private static final int PREVIEW_ICON_SIZE = 128; 
-    private static String searchFilterText = "";
+    private static String    searchFilterText = "";
+    private static Dimension dialogPreferredSize; 
     
     private TextureChoiceController controller;
     
@@ -533,7 +534,7 @@ public class TextureChoiceComponent extends JButton implements TextureChoiceView
         this.texturePanel = new WeakReference<TexturePanel>(texturePanel);
       }
       
-      public void collectionChanged(CollectionEvent<CatalogTexture> ev) {
+      public void collectionChanged(final CollectionEvent<CatalogTexture> ev) {
         // If controller was garbage collected, remove this listener from catalog
         final TexturePanel texturePanel = this.texturePanel.get();
         if (texturePanel == null) {
@@ -541,7 +542,19 @@ public class TextureChoiceComponent extends JButton implements TextureChoiceView
         } else {
           switch (ev.getType()) {
             case ADD:
-              texturePanel.availableTexturesList.setSelectedValue(ev.getItem(), true);
+              texturePanel.searchTextField.setText("");
+              // Select added texture only when the list is showing on screen to reduce the delay 
+              // spent on fully reloading the textures list after a language change
+              if (texturePanel.availableTexturesList.isShowing()) {
+                EventQueue.invokeLater(new Runnable() {
+                    public void run() {
+                      // Select value later to ensure scrolling works
+                      texturePanel.availableTexturesList.setSelectedValue(ev.getItem(), true);
+                    }
+                  });
+              } else {
+                texturePanel.availableTexturesList.clearSelection();
+              }
               break;
             case DELETE:
               texturePanel.availableTexturesList.clearSelection();
@@ -631,7 +644,7 @@ public class TextureChoiceComponent extends JButton implements TextureChoiceView
       JScrollPane scrollPane = new JScrollPane(this.availableTexturesList);
       scrollPane.getVerticalScrollBar().addAdjustmentListener(
           SwingTools.createAdjustmentListenerUpdatingScrollPaneViewToolTip(scrollPane));
-      scrollPane.setPreferredSize(new Dimension(220, scrollPane.getPreferredSize().height));
+      scrollPane.setPreferredSize(new Dimension(250, scrollPane.getPreferredSize().height));
       leftPanel.add(scrollPane, new GridBagConstraints(
           0, 1, 2, 1, 1, 1, GridBagConstraints.CENTER,
           GridBagConstraints.BOTH, new Insets(0, 0, 3, 0), 0, 0));
@@ -815,7 +828,12 @@ public class TextureChoiceComponent extends JButton implements TextureChoiceView
       dialog.setResizable(true);
       // Pack again because resize decorations may have changed dialog preferred size
       dialog.pack();
-      dialog.setMinimumSize(getPreferredSize());
+      dialog.setMinimumSize(dialog.getPreferredSize());
+      if (dialogPreferredSize != null
+          && dialogPreferredSize.width >= dialog.getWidth()
+          && dialogPreferredSize.height >= dialog.getHeight()) {
+        dialog.setSize(dialogPreferredSize);
+      }
       // Initialize search field value once list preferred size is set      
       searchTextField.setText(searchFilterText);
       // Add a listener that transfer focus to focusable field of texture panel when dialog is shown
@@ -841,11 +859,14 @@ public class TextureChoiceComponent extends JButton implements TextureChoiceView
       dialog.setVisible(true);
       dialog.dispose();
       ToolTipManager.sharedInstance().unregisterComponent(this.availableTexturesList);
+      dialogPreferredSize = dialog.getSize();
       searchFilterText = this.searchTextField.getText();
       if (Integer.valueOf(JOptionPane.OK_OPTION).equals(optionPane.getValue())) {
         HomeTexture selectedTexture = getSelectedTexture();
         this.controller.setTexture(selectedTexture);
-        this.controller.addRecentTexture(selectedTexture);
+        if (selectedTexture != null) {
+          this.controller.addRecentTexture(selectedTexture);
+        }
       }
     }
 
