@@ -206,8 +206,8 @@ public class HomeController3D implements Controller {
       }
     }
     storedCameras.add(0, camera);
-    // Ensure home stored cameras don't contain more than 20 cameras
-    while (storedCameras.size() > 20) {
+    // Ensure home stored cameras don't contain more cameras than allowed
+    while (storedCameras.size() > this.preferences.getStoredCamerasMaxCount()) {
       storedCameras.remove(storedCameras.size() - 1);
     }
     this.home.setStoredCameras(storedCameras);
