@@ -35,9 +35,10 @@ public class UserPreferencesController implements Controller {
    * The properties that may be edited by the view associated to this controller. 
    */
   public enum Property {LANGUAGE, UNIT, MAGNETISM_ENABLED, RULERS_VISIBLE, GRID_VISIBLE, 
-      FURNITURE_VIEWED_FROM_TOP, ROOM_FLOOR_COLORED_OR_TEXTURED, WALL_PATTERN,  
-      NEW_WALL_THICKNESS, NEW_WALL_HEIGHT, NEW_FLOOR_THICKNESS, FURNITURE_CATALOG_VIEWED_IN_TREE, NAVIGATION_PANEL_VISIBLE, 
-      AUTO_SAVE_DELAY_FOR_RECOVERY, AUTO_SAVE_FOR_RECOVERY_ENABLED}
+      FURNITURE_VIEWED_FROM_TOP, ROOM_FLOOR_COLORED_OR_TEXTURED, WALL_PATTERN, NEW_WALL_PATTERN,   
+      NEW_WALL_THICKNESS, NEW_WALL_HEIGHT, NEW_FLOOR_THICKNESS, FURNITURE_CATALOG_VIEWED_IN_TREE, 
+      NAVIGATION_PANEL_VISIBLE, AERIAL_VIEW_CENTERED_ON_SELECTION_ENABLED,
+      CHECK_UPDATES_ENABLED, AUTO_SAVE_DELAY_FOR_RECOVERY, AUTO_SAVE_FOR_RECOVERY_ENABLED}
   
   private final UserPreferences         preferences;
   private final ViewFactory             viewFactory;
@@ -49,15 +50,18 @@ public class UserPreferencesController implements Controller {
   private LengthUnit                    unit;
   private boolean                       furnitureCatalogViewedInTree;
   private boolean                       navigationPanelVisible;
+  private boolean                       aerialViewCenteredOnSelectionEnabled;
   private boolean                       magnetismEnabled;
   private boolean                       rulersVisible;
   private boolean                       gridVisible;
   private boolean                       furnitureViewedFromTop;
   private boolean                       roomFloorColoredOrTextured;
   private TextureImage                  wallPattern;
+  private TextureImage                  newWallPattern;
   private float                         newWallThickness;
   private float                         newWallHeight;
   private float                         newFloorThickness;
+  private boolean                       checkUpdatesEnabled;
   private int                           autoSaveDelayForRecovery;
   private boolean                       autoSaveForRecoveryEnabled;
 
@@ -125,17 +129,20 @@ public class UserPreferencesController implements Controller {
     setUnit(this.preferences.getLengthUnit());
     setFurnitureCatalogViewedInTree(this.preferences.isFurnitureCatalogViewedInTree());
     setNavigationPanelVisible(this.preferences.isNavigationPanelVisible());
+    setAerialViewCenteredOnSelectionEnabled(this.preferences.isAerialViewCenteredOnSelectionEnabled());
     setMagnetismEnabled(this.preferences.isMagnetismEnabled());
     setGridVisible(this.preferences.isGridVisible());
     setRulersVisible(this.preferences.isRulersVisible());
     setFurnitureViewedFromTop(this.preferences.isFurnitureViewedFromTop());
     setRoomFloorColoredOrTextured(this.preferences.isRoomFloorColoredOrTextured());
     setWallPattern(this.preferences.getWallPattern());
+    setNewWallPattern(this.preferences.getNewWallPattern());
     float minimumLength = getUnit().getMinimumLength();
     float maximumLength = getUnit().getMaximumLength();
     setNewWallThickness(Math.min(Math.max(minimumLength, this.preferences.getNewWallThickness()), maximumLength / 10));
     setNewWallHeight(Math.min(Math.max(minimumLength, this.preferences.getNewWallHeight()), maximumLength));
     setNewFloorThickness(Math.min(Math.max(minimumLength, this.preferences.getNewFloorThickness()), maximumLength / 10));
+    setCheckUpdatesEnabled(this.preferences.isCheckUpdatesEnabled());
     setAutoSaveDelayForRecovery(this.preferences.getAutoSaveDelayForRecovery());
     setAutoSaveForRecoveryEnabled(this.preferences.getAutoSaveDelayForRecovery() > 0);
   }  
@@ -227,6 +234,26 @@ public class UserPreferencesController implements Controller {
     return this.navigationPanelVisible;
   }
   
+  /**
+   * Sets whether aerial view should be centered on selection or not.
+   * @since 4.0
+   */
+  public void setAerialViewCenteredOnSelectionEnabled(boolean aerialViewCenteredOnSelectionEnabled) {
+    if (aerialViewCenteredOnSelectionEnabled != this.aerialViewCenteredOnSelectionEnabled) {
+      this.aerialViewCenteredOnSelectionEnabled = aerialViewCenteredOnSelectionEnabled;
+      this.propertyChangeSupport.firePropertyChange(Property.AERIAL_VIEW_CENTERED_ON_SELECTION_ENABLED.name(), 
+          !aerialViewCenteredOnSelectionEnabled, aerialViewCenteredOnSelectionEnabled);
+    }
+  }
+  
+  /**
+   * Returns whether aerial view should be centered on selection or not.
+   * @since 4.0
+   */
+  public boolean isAerialViewCenteredOnSelectionEnabled() {
+    return this.aerialViewCenteredOnSelectionEnabled;
+  }
+  
   /**
    * Sets whether magnetism is enabled or not.
    */
@@ -315,7 +342,7 @@ public class UserPreferencesController implements Controller {
   }
   
   /**
-   * Sets how furniture should be displayed in plan, and notifies
+   * Sets default walls top pattern in plan, and notifies
    * listeners of this change.
    */
   public void setWallPattern(TextureImage wallPattern) {
@@ -328,12 +355,34 @@ public class UserPreferencesController implements Controller {
   }
 
   /**
-   * Returns the wall pattern in plan.
+   * Returns the default walls top pattern in plan.
    */
   public TextureImage getWallPattern() {
     return this.wallPattern;
   }
   
+  /**
+   * Sets the edited new wall top pattern in plan, and notifies
+   * listeners of this change.
+   * @since 4.0
+   */
+  public void setNewWallPattern(TextureImage newWallPattern) {
+    if (this.newWallPattern != newWallPattern) {
+      TextureImage oldNewWallPattern = this.newWallPattern;
+      this.newWallPattern = newWallPattern;
+      this.propertyChangeSupport.firePropertyChange(Property.NEW_WALL_PATTERN.name(), 
+          oldNewWallPattern, newWallPattern);
+    }
+  }
+
+  /**
+   * Returns the edited new wall top pattern in plan.
+   * @since 4.0
+   */
+  public TextureImage getNewWallPattern() {
+    return this.newWallPattern;
+  }
+  
   /**
    * Sets the edited new wall thickness.
    */
@@ -388,6 +437,26 @@ public class UserPreferencesController implements Controller {
     return this.newFloorThickness;
   }
 
+  /**
+   * Sets whether updates should be checked or not.
+   * @since 4.0
+   */
+  public void setCheckUpdatesEnabled(boolean updatesChecked) {
+    if (updatesChecked != this.checkUpdatesEnabled) {
+      this.checkUpdatesEnabled = updatesChecked;
+      this.propertyChangeSupport.firePropertyChange(Property.CHECK_UPDATES_ENABLED.name(), 
+          !updatesChecked, updatesChecked);
+    }
+  }
+
+  /**
+   * Returns <code>true</code> if updates should be checked.
+   * @since 4.0
+   */
+  public boolean isCheckUpdatesEnabled() {
+    return this.checkUpdatesEnabled;
+  }
+
   /**
    * Sets the edited auto recovery save delay.
    */
@@ -425,6 +494,16 @@ public class UserPreferencesController implements Controller {
     return this.autoSaveForRecoveryEnabled;
   }
 
+  /**
+   * Checks if some updates are available.
+   * @since 4.0
+   */
+  public void checkUpdates() {
+    if (this.homeController != null) {
+      this.homeController.checkUpdates(false);
+    }
+  }
+
   /**
    * Returns <code>true</code> if language libraries can be imported.
    */
@@ -441,6 +520,13 @@ public class UserPreferencesController implements Controller {
     }
   }
 
+  /**
+   * Resets the displayed flags of action tips.
+   */
+  public void resetDisplayedActionTips() {
+    this.preferences.resetIgnoredActionTips();
+  }
+
   /**
    * Controls the modification of user preferences.
    */
@@ -449,23 +535,19 @@ public class UserPreferencesController implements Controller {
     this.preferences.setUnit(getUnit());
     this.preferences.setFurnitureCatalogViewedInTree(isFurnitureCatalogViewedInTree());
     this.preferences.setNavigationPanelVisible(isNavigationPanelVisible());
+    this.preferences.setAerialViewCenteredOnSelectionEnabled(isAerialViewCenteredOnSelectionEnabled());
     this.preferences.setMagnetismEnabled(isMagnetismEnabled());
     this.preferences.setRulersVisible(isRulersVisible());
     this.preferences.setGridVisible(isGridVisible());
     this.preferences.setFurnitureViewedFromTop(isFurnitureViewedFromTop());
     this.preferences.setFloorColoredOrTextured(isRoomFloorColoredOrTextured());
     this.preferences.setWallPattern(getWallPattern());
+    this.preferences.setNewWallPattern(getNewWallPattern());
     this.preferences.setNewWallThickness(getNewWallThickness());
     this.preferences.setNewWallHeight(getNewWallHeight());
     this.preferences.setNewFloorThickness(getNewFloorThickness());
+    this.preferences.setCheckUpdatesEnabled(isCheckUpdatesEnabled());
     this.preferences.setAutoSaveDelayForRecovery(isAutoSaveForRecoveryEnabled()
         ? getAutoSaveDelayForRecovery() : 0);
   }
-
-  /**
-   * Resets the displayed flags of action tips.
-   */
-  public void resetDisplayedActionTips() {
-    this.preferences.resetIgnoredActionTips();
-  }
 }
